.. _cleaning_a_dataframe_ref:
.. currentmodule:: skrub

Cleaning a dataframe
====================

.. autosummary::
   :toctree: generated/
   :template: function.rst
   :nosignatures:

   deduplicate
